@@ -47,7 +47,7 @@ if xdg_cache_home == "":
 We used this directory to create a `isbg/` one to store cached data:
     * lock file.
     * password file.
-    * chached lists of ``uids``.
+    * cached lists of ``uids``.
 
 Note:
     For best `xdg_cache_home` detection, install *python-xdg*.
@@ -57,7 +57,7 @@ Note:
 """
 
 
-__version__ = "2.3.0"  #: The current isbg version
+__version__ = "2.3.1"  #: The current isbg version
 
 __license__ = \
     """License GPLv3: GNU GPL version 3 https://gnu.org/licenses/gpl.html
@@ -395,6 +395,10 @@ class ISBG(object):
     def pastuid_write(self, uidvalidity, origpastuids, newpastuids,
                       folder='inbox'):
         """Write the uids in a file for the folder."""
+        if self.dryrun:
+            self.logger.debug(__(('Skipping pastuids write due to dryrun')))
+            return
+
         if self.trackfile is None:
             self.trackfile = ISBG.set_filename(self.imapsets, "track")
 
